@@ -3,7 +3,7 @@ use warnings;
 use strict;
 use Carp;
 use utf8;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use C::Tokenize ':all';
 use Text::LineNumber;
 use File::Slurper 'read_text';
@@ -66,7 +66,7 @@ sub check_svpv
 	    $o->report ("$lvar not a constant type");
 	}
 	if ($arg2_type && $arg2_type !~ /\bSTRLEN\b/) {
-	    $o->report ("$lvar is not a STRLEN variable");
+	    $o->report ("$arg2 is not a STRLEN variable ($arg2_type)");
 	}
     }
 }
@@ -81,6 +81,16 @@ sub check_malloc
     }
 }
 
+# Look for a Perl_ prefix before functions.
+
+sub check_perl_prefix
+{
+    my ($o) = @_;
+    while ($o->{xs} =~ /\b(Perl_$word_re)\b/g) {
+	$o->report ("Remove the 'Perl_' prefix from $1");
+    }
+}
+
 # Regular expression to match a C declaration.
 
 my $declare_re = qr/
@@ -187,6 +197,7 @@ sub check
     $o->read_declarations ();
     $o->check_svpv ();
     $o->check_malloc ();
+    $o->check_perl_prefix ();
     $o->{xs} = undef;
     $o->cleanup ();
 }
